@@ -3,6 +3,7 @@ import logging
 import json
 import subprocess
 import atexit
+import time
 from .commit import Commit
 
 class Namespace:
@@ -33,6 +34,12 @@ class Namespace:
     def url(self):
         return self.__json["url"]
 
+    def created_date(self):
+        return self.__json["createdDate"]
+
+    def terminated_date(self):
+        return self.__json["terminatedDate"]
+
 class NamespaceApi:
     """Namespace api"""
 
@@ -63,11 +70,15 @@ class NamespaceApi:
         if namespaces == None:
             return None
 
+        removed = None
         for ns in namespaces:
+            if ns.phase() == "REMOVED":
+                removed = ns
+                continue
             if ns.alias() == instance_name:
                 return ns
 
-        return None
+        return removed
 
     def get_by_id(self, instance_id):
         r = self.__staroid._api_get(
@@ -224,7 +235,7 @@ class NamespaceApi:
             logging.error("Can not get namespace resources {}", r.status_code)
             return None
 
-    def _is_tunnel_running(self, instance_name):
+    def is_tunnel_running(self, instance_name):
         if instance_name in self.__tunnel_processes:
             p = self.__tunnel_processes[instance_name]
             p.poll()
@@ -233,7 +244,7 @@ class NamespaceApi:
             return False
 
     def start_tunnel(self, instance_name, tunnels):
-        if self._is_tunnel_running(instance_name):
+        if self.is_tunnel_running(instance_name):
             return
 
         chisel_path = self.__staroid.get_chisel_path()
@@ -280,7 +291,7 @@ class NamespaceApi:
                 p.kill() # supported from python 2.6
 
     def stop_tunnel(self, instance_name):
-        if self._is_tunnel_running(instance_name):
+        if self.is_tunnel_running(instance_name):
             self.__tunnel_processes[instance_name].kill()
             del self.__tunnel_processes[instance_name]
 
